<template>
  <div class="fixed inset-0 bg-gray-600 bg-opacity-50 overflow-y-auto h-full w-full z-50" v-if="showModal">
    <div class="relative top-20 mx-auto p-5 border w-full max-w-2xl shadow-lg rounded-md bg-white">
      <div class="flex justify-between items-center mb-4">
        <h3 class="text-lg font-medium">Configure Classification Agent</h3>
        <button @click="$emit('close')" class="text-gray-500 hover:text-gray-700">
          <svg class="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12" />
          </svg>
        </button>
      </div>
      
      <form @submit.prevent="$emit('saveClassificationSettings')" class="space-y-4">
        <div>
          <label class="block text-sm font-medium text-gray-700">Status</label>
          <div class="flex items-center space-x-4 mt-1">
            <label class="inline-flex items-center">
              <input type="radio" v-model="classificationForm.enabled" :value="true" class="form-radio text-indigo-600">
              <span class="ml-2">Enabled</span>
            </label>
            <label class="inline-flex items-center">
              <input type="radio" v-model="classificationForm.enabled" :value="false" class="form-radio text-indigo-600">
              <span class="ml-2">Disabled</span>
            </label>
          </div>
        </div>

        <div v-if="classificationForm.enabled">
          <label class="block text-sm font-medium text-gray-700 mb-2">Categories</label>
          
          <div v-for="(category, index) in classificationForm.categories" :key="index" class="flex items-center mb-2">
            <input type="text" v-model="classificationForm.categories[index]" class="flex-grow rounded-md border-gray-300 shadow-sm focus:border-indigo-500 focus:ring-indigo-500 sm:text-sm">
            <button type="button" @click="removeCategory(index)" class="ml-2 text-red-600 hover:text-red-800">
              <svg class="h-5 w-5" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19 7l-.867 12.142A2 2 0 0116.138 21H7.862a2 2 0 01-1.995-1.858L5 7m5 4v6m4-6v6m1-10V4a1 1 0 00-1-1h-4a1 1 0 00-1 1v3M4 7h16" />
              </svg>
            </button>
          </div>
          
          <button type="button" @click="addCategory" class="mt-2 inline-flex items-center px-3 py-1 border border-transparent text-sm leading-4 font-medium rounded-md text-indigo-700 bg-indigo-100 hover:bg-indigo-200 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
            <svg class="h-4 w-4 mr-1" fill="none" viewBox="0 0 24 24" stroke="currentColor">
              <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 6v6m0 0v6m0-6h6m-6 0H6" />
            </svg>
            Add Category
          </button>
        </div>

        <div class="flex justify-end space-x-3 mt-6">
          <button type="button" @click="$emit('close')" class="px-4 py-2 border border-gray-300 rounded-md shadow-sm text-sm font-medium text-gray-700 bg-white hover:bg-gray-50">
            Cancel
          </button>
          <button type="submit" class="px-4 py-2 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-blue-600 hover:bg-blue-700">
            Save
          </button>
        </div>
      </form>
    </div>
  </div>
</template>

<script>
export default {
  props: {
    showModal: {
      type: Boolean,
      required: true
    },
    classificationForm: {
      type: Object,
      required: true
    }
  },
  
  emits: ['close', 'saveClassificationSettings'],
  
  setup(props) {
    function addCategory() {
      props.classificationForm.categories.push('');
    }
    
    function removeCategory(index) {
      props.classificationForm.categories.splice(index, 1);
    }
    
    return {
      addCategory,
      removeCategory
    };
  }
};
</script>
